==> haskell-interpolatedstring-perl6-1.0.2-287-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 interpolatedstring-perl6
version:              1.0.2
visibility:           public
id:                   interpolatedstring-perl6-1.0.2-BmxV6WoLpsaI3sw3BGb7Af
key:                  interpolatedstring-perl6-1.0.2-BmxV6WoLpsaI3sw3BGb7Af
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            stable
synopsis:             QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.

category:             Data
abi:                  1e568354a2b6be57a738361c4aebbf15
exposed:              True
exposed-modules:      Text.InterpolatedString.Perl6
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/interpolatedstring-perl6-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolatedstring-perl6
hs-libraries:         HSinterpolatedstring-perl6-1.0.2-BmxV6WoLpsaI3sw3BGb7Af
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    haskell-src-meta-0.8.12-3aFnqQE0XF33tohreEbzmX
    template-haskell-2.18.0.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock

haddock-html:         /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolatedstring-perl6-1.0.2-289-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 interpolatedstring-perl6
version:              1.0.2
visibility:           public
id:                   interpolatedstring-perl6-1.0.2-EtZDEJYLsdH767le4pvMyb
key:                  interpolatedstring-perl6-1.0.2-EtZDEJYLsdH767le4pvMyb
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            stable
synopsis:             QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.

category:             Data
abi:                  116ab7a18e1908ae0000519a70be62a1
exposed:              True
exposed-modules:      Text.InterpolatedString.Perl6
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/interpolatedstring-perl6-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolatedstring-perl6
hs-libraries:         HSinterpolatedstring-perl6-1.0.2-EtZDEJYLsdH767le4pvMyb
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    haskell-src-meta-0.8.12-Fe5kGltKJxeIZkKj5WAOn4
    template-haskell-2.18.0.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock

haddock-html:         /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
